@@ -16,12 +16,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
 #include <bakery/App/App_WithDoc.h>
 #include <bakery/App/Dialog_OfferSave.h>
 #include <gconfmm.h>
 #include <giomm.h>
-#include <libintl.h>
 #include <algorithm>
+#include <glibmm/i18n-lib.h>
 
 //#include <gtk/gtkfilesel.h>
 
@@ -93,7 +94,7 @@ bool App_WithDoc::open_document_from_data(const guchar* data, std::size_t length
 
   if(bOpenFailed)
   {
-    ui_warning(gettext("Open failed."), gettext("The document could not be opened."));
+    ui_warning(_("Open failed."), _("The document could not be opened."));
 
     return false; //failed.
   }
@@ -132,7 +133,7 @@ bool App_WithDoc::open_document(const Glib::ustring& file_uri)
     }
 
     //Tell user that it's already open:
-    ui_warning(gettext("Document already open"), gettext("This document is already open."));
+    ui_warning(_("Document already open"), _("This document is already open."));
 
     return true; //success.
   }
@@ -185,7 +186,7 @@ bool App_WithDoc::open_document(const Glib::ustring& file_uri)
 
     if(bOpenFailed)
     {
-      ui_warning(gettext("Open failed."), gettext("The document could not be opened."));
+      ui_warning(_("Open failed."), _("The document could not be opened."));
 
       if(bUsingNewInstance)
       {
@@ -278,7 +279,7 @@ void App_WithDoc::on_menu_file_saveas()
 
       if(!bTest)
       {
-        ui_warning(gettext("Save failed."), gettext("There was an error while saving the file. Your changes have not been saved."));
+        ui_warning(_("Save failed."), _("There was an error while saving the file. Your changes have not been saved."));
       }
       else
       {
@@ -329,7 +330,7 @@ void App_WithDoc::on_menu_file_save()
       else
       {
         //The save failed. Tell the user and don't do anything else:
-        ui_warning(gettext("Save failed."), gettext("There was an error while saving the file. Your changes have not been saved."));
+        ui_warning(_("Save failed."), _("There was an error while saving the file. Your changes have not been saved."));
 
         cancel_close_or_exit();
       }
