@@ -24,11 +24,18 @@
 #include <bakery/Document/Document.h>
 #include <gtkmm/toolbutton.h>
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern "C" {
 typedef struct _EggRecentItem EggRecentItem;
-typedef struct _EggRecentModel EggRecentModel;
 }
 
+// We do not include gtkmm/recentchooser.h so that this still compiles
+// with gtkmm-2.6
+namespace Gtk {
+  class RecentChooser;
+}
+#endif // DOXYGEN_SHOULD_SKIP_THIS
+
 namespace Bakery
 {
 
@@ -55,13 +62,11 @@ public:
 
   virtual void init(); //Unique final overrider.
 
-  typedef sigc::slot<void, EggRecentItem*> RecentFileSlot;
-
 protected:
   virtual void init_menus_file(); //overridden to add open/save/save as.
   virtual void init_menus_file_recentfiles(const Glib::ustring& path); // call this in init_menus_file()
   virtual void init_toolbars(); //overridden to add open/save
-  
+
   virtual void document_history_add(const Glib::ustring& file_uri); //overridden.
   virtual void document_history_remove(const Glib::ustring& file_uri); //overridden.
 
@@ -73,12 +78,10 @@ protected:
   virtual void ui_show_modification_status();
   virtual enumSaveChanges ui_offer_to_save_changes();
 
-  void on_recent_files_activate(EggRecentItem* item);
+  void on_recent_files_activate(Gtk::RecentChooser& recent_chooser);
 
   //Menu stuff:
   Glib::RefPtr<Gtk::Action> m_action_save, m_action_saveas;
-  EggRecentModel* m_recent_files_model;
-  RecentFileSlot m_slot_recent_files_activate;
 };
 
 } //namespace
