@@ -16,10 +16,11 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "config.h"
 #include "bakery/Document/Document.h"
 #include <giomm.h>
 //#include <fstream>
-#include <libintl.h>
+#include <glibmm/i18n-lib.h>
 
 namespace Bakery
 {
@@ -356,7 +357,7 @@ Glib::ustring Document::util_file_uri_get_name(const Glib::ustring& file_uri, co
   //Show untitled explicitly:
   //Also happens for file_uris with path but no name. e.g. /sub/sub/, which shouldn't happen.
   if(strResult.empty())
-    strResult = gettext("Untitled");
+    strResult = _("Untitled");
 
   return strResult;
 }
